/*
 * Copyright (c) 2016 BiTel Inc. All rights reserved.
*/
package ru.bitel.mybgbilling.kernel.realm;

import java.io.IOException;

import jakarta.enterprise.inject.Instance;
import jakarta.inject.Inject;
import jakarta.servlet.ServletException;
import jakarta.servlet.annotation.WebServlet;
import jakarta.servlet.http.HttpServlet;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;

import ru.bitel.bgbilling.common.BGException;
import ru.bitel.common.Utils;
import ru.bitel.mybgbilling.kernel.common.CaptchaRenderer;
import ru.bitel.mybgbilling.kernel.common.MyApplicationBean;

@WebServlet("/captcha")
public class CaptchaServlet
	extends HttpServlet
{
	private static final long serialVersionUID = 7513003147334086949L;

	@Inject
	private Instance<MyApplicationBean> application;

	@Override
	protected void doGet( HttpServletRequest request, HttpServletResponse response )
		throws ServletException, IOException
	{
		final CaptchaRenderer captchaRenderer = application.get().getCaptchaRenderer();

		try
		{
			String type = request.getParameter( "type" );
			if( Utils.isBlankString( type ) )
			{
				return;
			}

			switch( type )
			{
				case "login":
				case "passwordReset":
					break;

				default:
					return;
			}

			String captcha = captchaRenderer.render( response.getOutputStream(), false );
			
			log( captcha );

			request.getSession( true ).setAttribute( type + ".captcha.value", captcha );

			response.setContentType( "image/png" );

			// Set standard HTTP/1.1 no-cache headers.
			response.setHeader( "Cache-Control", "private, no-store, no-cache, must-revalidate" );

			// Set standard HTTP/1.0 no-cache header.
			response.setHeader( "Pragma", "no-cache" );
		}
		catch( BGException e )
		{
			throw new ServletException( e );
		}
	}
}
